[Libreoffice-commits] .: 4 commits - pyuno/source qadevOOo/tests sw/source

Michael Stahl mst at kemper.freedesktop.org
Wed Mar 7 02:19:52 PST 2012


 pyuno/source/module/pyuno.cxx                    |   13 ++-
 pyuno/source/module/uno.py                       |   14 ++-
 qadevOOo/tests/java/ifc/beans/_XPropertySet.java |    4 +
 sw/source/core/layout/atrfrm.cxx                 |   22 ++---
 sw/source/core/layout/colfrm.cxx                 |    2 
 sw/source/core/layout/findfrm.cxx                |   45 +++++------
 sw/source/core/layout/flycnt.cxx                 |   33 ++++----
 sw/source/core/layout/flyincnt.cxx               |    2 
 sw/source/core/layout/pagedesc.cxx               |    7 -
 sw/source/core/layout/paintfrm.cxx               |   52 ++++++-------
 sw/source/core/layout/wsfrm.cxx                  |   90 +++++++++++------------
 11 files changed, 148 insertions(+), 136 deletions(-)

New commits:
commit 387389b644b91808fdee74846b2d855382f48ed7
Author: David Bolen <db3l.net at gmail.com>
Date:   Wed Mar 7 11:13:52 2012 +0100

    fdo#46926: fix UNO struct comparison in Python 2
    
    This requires setting a rich comparison flag in Python 2, while Python 3
    uses rich comparison by default.
    (regression from a09ce46818fd4d5e08b3af9a478501cd8ef5b4fe)

diff --git a/pyuno/source/module/pyuno.cxx b/pyuno/source/module/pyuno.cxx
index b7724c7..555fefd 100644
--- a/pyuno/source/module/pyuno.cxx
+++ b/pyuno/source/module/pyuno.cxx
@@ -641,9 +641,16 @@ static PyObject* PyUNO_cmp( PyObject *self, PyObject *that, int op )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
-    return Py_False;
+    return (op == Py_EQ ? Py_False : Py_True);
 }
 
+/* Python 2 has a tp_flags value for rich comparisons.  Python 3 does not (on by default) */
+#ifdef Py_TPFLAGS_HAVE_RICHCOMPARE
+#define TP_FLAGS (Py_TPFLAGS_HAVE_RICHCOMPARE)
+#else
+#define TP_FLAGS 0
+#endif
+
 static PyTypeObject PyUNOType =
 {
     PyVarObject_HEAD_INIT( &PyType_Type, 0 )
@@ -654,7 +661,7 @@ static PyTypeObject PyUNOType =
     (printfunc) 0,
     (getattrfunc) PyUNO_getattr,
     (setattrfunc) PyUNO_setattr,
-    0,
+    (cmpfunc) 0,
     (reprfunc) PyUNO_repr,
     0,
     0,
@@ -665,7 +672,7 @@ static PyTypeObject PyUNOType =
     (getattrofunc)0,
     (setattrofunc)0,
     NULL,
-    0,
+    TP_FLAGS,
     NULL,
     (traverseproc)0,
     (inquiry)0,
commit 4634cbc237239da771e0f6a81f78171ecec726ba
Author: David Bolen <db3l.net at gmail.com>
Date:   Wed Mar 7 11:07:42 2012 +0100

    fdo#46859: adapt string type checks to work with both Python 2 and 3
    
    (regression from a09ce46818fd4d5e08b3af9a478501cd8ef5b4fe)

diff --git a/pyuno/source/module/uno.py b/pyuno/source/module/uno.py
index f93ac5e..e82d2fe 100644
--- a/pyuno/source/module/uno.py
+++ b/pyuno/source/module/uno.py
@@ -35,6 +35,12 @@ try:
 except ImportError:
     import builtins as __builtin__
 
+try:
+    unicode
+except NameError:
+    # Python 3 compatibility
+    unicode = str
+
 import socket # since on Windows sal3.dll no longer calls WSAStartup
 
 # all functions and variables starting with a underscore (_) must be considered private
@@ -159,9 +165,9 @@ class Bool(object):
        Note: This class is deprecated. Use python's True and False directly instead
     """
     def __new__(cls, value):
-        if isinstance(value, str) and value == "true":
+        if isinstance(value, (str, unicode)) and value == "true":
             return True
-        if isinstance(value, str) and value == "false":
+        if isinstance(value, (str, unicode)) and value == "false":
             return False
         if value:
             return True
@@ -171,7 +177,7 @@ class Char:
     "Represents a UNO char, use an instance of this class to explicitly pass a char to UNO"
     # @param value pass a Unicode string with length 1
     def __init__(self,value):
-        assert isinstance(value, str)
+        assert isinstance(value, unicode)
         assert len(value) == 1
         self.value=value
 
@@ -179,7 +185,7 @@ class Char:
         return "<Char instance %s>" % (self.value, )
         
     def __eq__(self, that):
-        if isinstance(that, str):
+        if isinstance(that, (str, unicode)):
             if len(that) > 1:
                 return False
             return self.value == that[0]
commit 73867da36960adf8b79ff34c7094c63aa5a05940
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Mar 6 23:51:54 2012 +0100

    qadevOOo: _XPropertySet.java: fix unrealistic expectations:
    
    We can't assume that when setting properties whose semantics we don't
    know to random values in an arbitrary order, a non-changing value
    indicates any kind of error.
    The only real error this test can detect is if setting a property
    crashes.

diff --git a/qadevOOo/tests/java/ifc/beans/_XPropertySet.java b/qadevOOo/tests/java/ifc/beans/_XPropertySet.java
index 07efacb..09e933f 100644
--- a/qadevOOo/tests/java/ifc/beans/_XPropertySet.java
+++ b/qadevOOo/tests/java/ifc/beans/_XPropertySet.java
@@ -319,11 +319,15 @@ public class _XPropertySet extends MultiMethodTest {
                         "property '"+ propertyName+"'");
                     e.printStackTrace(log);
                 } // end of try-catch
+                /*  this is stupid: we can't set properties whose semantics we
+                 *  don't know to random values in an arbitrary order and
+                 *  expect that to actually work.
                 if( gValue.equals(sValue) )
                 {
                     log.println("setting property '"+ propertyName+"' failed");
                     error = true;
                 }
+                */
             }
             tRes.tested("setPropertyValue()",!error);
         } //endif
commit 86d316f9737e2bbe37968b9b9b32bd9aa4564077
Author: Michael Stahl <mstahl at redhat.com>
Date:   Tue Mar 6 17:51:10 2012 +0100

    sw: tweak comment translations
    
    037d14ce and following

diff --git a/sw/source/core/layout/atrfrm.cxx b/sw/source/core/layout/atrfrm.cxx
index 63d3dc3..920eb52 100644
--- a/sw/source/core/layout/atrfrm.cxx
+++ b/sw/source/core/layout/atrfrm.cxx
@@ -178,10 +178,10 @@ void DelHFFormat( SwClient *pToRemove, SwFrmFmt *pFmt )
         return;
     }
 
-    // Are the only frms registred?
+    // Anything other than frames registered?
     sal_Bool bDel = sal_True;
     {
-        // Brace, because the DTOR of SwClientIter resets the flag bTreeChg.
+        // nested scope because DTOR of SwClientIter resets the flag bTreeChg.
         // It's suboptimal if the format is deleted beforehand.
         SwClientIter aIter( *pFmt );        // TODO
         SwClient *pLast = aIter.GoStart();
@@ -773,7 +773,7 @@ bool SwFmtPageDesc::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
         case MID_PAGEDESC_PAGEDESCNAME:
             /* Doesn't work, because the attribute doesn't need the name but a
              * pointer to the PageDesc (it's a client of it). The pointer can
-             * only be requested using the name of the document.
+             * only be requested from the document using the name.
              */
         default:
             OSL_ENSURE( !this, "unknown MemberId" );
@@ -982,7 +982,7 @@ void SwFmtCol::Calc( sal_uInt16 nGutterWidth, sal_uInt16 nAct )
     if(!GetNumCols())
         return;
     //First set the column widths with the current width, then calculate the
-    //column's with using the requested total width.
+    //column's requested width using the requested total width.
 
     const sal_uInt16 nGutterHalf = nGutterWidth ? nGutterWidth / 2 : 0;
 
@@ -2535,7 +2535,7 @@ SwRect SwFrmFmt::FindLayoutRect( const sal_Bool bPrtArea, const Point* pPoint,
     SwFrm *pFrm = 0;
     if( ISA( SwSectionFmt ) )
     {
-        // get the frame::Frame using Node2Layout
+        // get the Frame using Node2Layout
         SwSectionNode* pSectNd = ((SwSectionFmt*)this)->GetSectionNode();
         if( pSectNd )
         {
@@ -2544,9 +2544,9 @@ SwRect SwFrmFmt::FindLayoutRect( const sal_Bool bPrtArea, const Point* pPoint,
 
             if( pFrm && !pFrm->KnowsFormat(*this) )
             {
-                // the section doesn't have his own frame::Frame, so if someone
+                // the Section doesn't have his own Frame, so if someone
                 // needs the real size, we have to implement this by requesting
-                // frame::Frame from the end.
+                // the matching Frame from the end.
                 // PROBLEM: what happens if SectionFrames overlaps multiple
                 //          pages?
                 if( bPrtArea )
@@ -2707,11 +2707,11 @@ SwFlyFrmFmt::~SwFlyFrmFmt()
 }
 
 //Creates the Frms if the format describes a paragraph-bound frame.
-//MA: 1994-02-14, creates the Frms also for page-bound borders.
+//MA: 1994-02-14, creates the Frms also for frames anchored at page.
 
 void SwFlyFrmFmt::MakeFrms()
 {
-    // does a layout even exists?
+    // is there a layout?
     if( !GetDoc()->GetCurrentViewShell() )
         return; //swmod 071108//swmod 071225
 
@@ -2733,8 +2733,8 @@ void SwFlyFrmFmt::MakeFrms()
         if( aAnchorAttr.GetCntntAnchor() )
         {
             //First search in the content because this is O(1)
-            //This can go wrong for linked borders because in this case it's
-            //possible, that no frame::Frame exists for this content.
+            //This can go wrong for linked frames because in this case it's
+            //possible, that no Frame exists for this content.
             //In such a situation we also need to search from StartNode to
             //FrameFormat.
             SwNodeIndex aIdx( aAnchorAttr.GetCntntAnchor()->nNode );
diff --git a/sw/source/core/layout/colfrm.cxx b/sw/source/core/layout/colfrm.cxx
index d88942a..31fb081 100644
--- a/sw/source/core/layout/colfrm.cxx
+++ b/sw/source/core/layout/colfrm.cxx
@@ -374,7 +374,7 @@ void SwLayoutFrm::AdjustColumns( const SwFmtCol *pAttr, sal_Bool bAdjustAttribut
 
             // With this, the ColumnBodyFrms from page columns gets adjusted and
             // their bFixHeight flag is set so they won't shrink/grow.
-            // Don't use the flag with border columns because BodyFrms in border
+            // Don't use the flag with frame columns because BodyFrms in frame
             // columns can grow/shrink.
             if( IsBodyFrm() )
                 ((SwLayoutFrm*)pCol)->Lower()->ChgSize( aColSz );
diff --git a/sw/source/core/layout/flycnt.cxx b/sw/source/core/layout/flycnt.cxx
index 0e21be6..3aa99b3 100644
--- a/sw/source/core/layout/flycnt.cxx
+++ b/sw/source/core/layout/flycnt.cxx
@@ -118,9 +118,8 @@ void SwFlyAtCntFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
 
         const sal_Bool bBodyFtn = (pCntnt->IsInDocBody() || pCntnt->IsInFtn());
 
-        //Search the new anchor usind the NodeIdx, based on the old and new
-        //NodeIdx can also be discovered in which direction searching has to be
-        //done.
+        // Search the new anchor using the NodeIdx; the relation between old
+        // and new NodeIdx determines the search direction
         const SwNodeIndex aNewIdx( pAnch->GetCntntAnchor()->nNode );
         SwNodeIndex aOldIdx( *pCntnt->GetNode() );
 
@@ -499,10 +498,10 @@ void SwFlyAtCntFrm::MakeAll()
                 if ( bExtra && Lower() && !Lower()->GetValidPosFlag() )
                 {
                     // If a multi column frame leaves invalid columns because of
-                    // a position change, we loop once more and formate
+                    // a position change, we loop once more and format
                     // our content using FormatWidthCols again.
-                        _InvalidateSize();
-                    bExtra = sal_False; // Get sure to only make one additional loop run
+                    _InvalidateSize();
+                    bExtra = sal_False; // Ensure only one additional loop run
                 }
             } while ( !IsValid() && !bOsz &&
                       // #i3317#
@@ -587,7 +586,7 @@ const SwFrm * MA_FASTCALL lcl_CalcDownDist( SwDistance &rRet,
                                          const SwCntntFrm *pCnt )
 {
     rRet.nSub = 0;
-    //If the point stays inside the Cnt everything is clear already; the Cntn
+    //If the point stays inside the Cnt everything is clear already; the Cntnt
     //automatically has a distance of 0.
     if ( pCnt->Frm().IsInside( rPt ) )
     {
@@ -901,7 +900,7 @@ sal_uLong MA_FASTCALL lcl_FindCntDiff( const Point &rPt, const SwLayoutFrm *pLay
                           const SwCntntFrm *& rpCnt,
                           const sal_Bool bBody, const sal_Bool bFtn )
 {
-    //Searches the nearest Cnt to the point belows pLay. The reference point of
+    // Searches below pLay the nearest Cnt to the point. The reference point of
     //the Cntnts is always the left upper corner.
     //The Cnt should preferably be above the point.
 
@@ -971,7 +970,7 @@ const SwCntntFrm * MA_FASTCALL lcl_FindCnt( const Point &rPt, const SwCntntFrm *
 
     //First the nearest Cntnt inside the page which contains the Cntnt is
     //searched. Starting from this page the pages in both directions need to
-    //take into account. If possible a Cntnt is returned whose Y-position is
+    //be considered. If possible a Cntnt is returned whose Y-position is
     //above the point.
     const SwCntntFrm  *pRet, *pNew;
     const SwLayoutFrm *pLay = pCnt->FindPageFrm();
@@ -1064,7 +1063,7 @@ const SwCntntFrm *FindAnchor( const SwFrm *pOldAnch, const Point &rNew,
                               const sal_Bool bBodyOnly )
 {
     //Search the nearest Cnt around the given document position in the text
-    //flow. The omited anchor is the starting Frm.
+    //flow. The given anchor is the starting Frm.
     const SwCntntFrm* pCnt;
     if ( pOldAnch->IsCntntFrm() )
     {
@@ -1090,7 +1089,7 @@ const SwCntntFrm *FindAnchor( const SwFrm *pOldAnch, const Point &rNew,
     Point aNew( rNew );
     if ( bBody )
     {
-        //#38848 drag from page border into the body.
+        //#38848 drag from page margin into the body.
         const SwFrm *pPage = pCnt->FindPageFrm();
         ::lcl_PointToPrt( aNew, pPage->GetUpper() );
         SwRect aTmp( aNew, Size( 0, 0 ) );
@@ -1102,8 +1101,8 @@ const SwCntntFrm *FindAnchor( const SwFrm *pOldAnch, const Point &rNew,
         return pCnt;
     else if ( pOldAnch->IsInDocBody() || pOldAnch->IsPageFrm() )
     {
-        //Maybe the selected anchor is on the same page like the current anchor.
-        //Whit this we won't run into problems with the columns.
+        // Maybe the selected anchor is on the same page as the current anchor.
+        // With this we won't run into problems with the columns.
         Point aTmp( aNew );
         const SwCntntFrm *pTmp = pCnt->FindPageFrm()->
                                         GetCntntPos( aTmp, sal_False, sal_True, sal_False );
@@ -1196,7 +1195,7 @@ const SwCntntFrm *FindAnchor( const SwFrm *pOldAnch, const Point &rNew,
 
     //If we couldn't find one in both directions, we'll search the Cntnt whose
     //left upper corner is the nearest to the point. Such a situation may
-    //happen, if the point doesn't lay in the text flow but in any border.
+    //happen, if the point doesn't lay in the text flow but in any margin.
     if ( nDownLst.nMain == LONG_MAX && nUpLst.nMain == LONG_MAX )
     {
         // If an OLE objects, which is contained in a fly frame
@@ -1246,7 +1245,7 @@ void SwFlyAtCntFrm::SetAbsPos( const Point &rNew )
 
     if ( pCnt->IsInDocBody() )
     {
-        //#38848 drag from page border into the body.
+        //#38848 drag from page margin into the body.
         pTmpPage = pCnt->FindPageFrm();
         ::lcl_PointToPrt( aNew, pTmpPage->GetUpper() );
         SwRect aTmp( aNew, Size( 0, 0 ) );
@@ -1297,8 +1296,8 @@ void SwFlyAtCntFrm::SetAbsPos( const Point &rNew )
 
     if ( pCnt->IsFollow() )
     {
-        //Flys are never attached to the flow but always to the master which
-        //we're going to search now.
+        // Flys are never attached to the follow but always to the master,
+        // which we're going to search now.
         const SwCntntFrm *pOriginal = pCnt;
         const SwCntntFrm *pFollow = pCnt;
         while ( pCnt->IsFollow() )
diff --git a/sw/source/core/layout/flyincnt.cxx b/sw/source/core/layout/flyincnt.cxx
index 8b57281..676191b 100644
--- a/sw/source/core/layout/flyincnt.cxx
+++ b/sw/source/core/layout/flyincnt.cxx
@@ -154,7 +154,7 @@ void SwFlyInCntFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
 |*
 |*  SwFlyInCntFrm::Format()
 |*
-|*  Description:        Here the content gets formated initially.
+|*  Here the content gets formatted initially.
 |*
 |*************************************************************************/
 void SwFlyInCntFrm::Format( const SwBorderAttrs *pAttrs )
diff --git a/sw/source/core/layout/pagedesc.cxx b/sw/source/core/layout/pagedesc.cxx
index 38ece9d..04fd78c 100644
--- a/sw/source/core/layout/pagedesc.cxx
+++ b/sw/source/core/layout/pagedesc.cxx
@@ -176,7 +176,7 @@ sal_Bool SwPageDesc::GetInfo( SfxPoolItem & rInfo ) const
 |*
 |*                SwPageDesc::SetRegisterFmtColl()
 |*
-|*    Description       sets the template for the grid alignment
+|*    Description       sets the style for the grid alignment
 |*
 *************************************************************************/
 
@@ -198,7 +198,7 @@ void SwPageDesc::SetRegisterFmtColl( const SwTxtFmtColl* pFmt )
 |*
 |*                SwPageDesc::GetRegisterFmtColl()
 |*
-|*    Description       retrieves the template for the grid alignment
+|*    Description       retrieves the style for the grid alignment
 |*
 *************************************************************************/
 
@@ -258,8 +258,7 @@ void SwPageDesc::RegisterChange()
 |*
 |*                SwPageDesc::Modify()
 |*
-|*    Description       acts particularly if the template of the grid alignment
-|*                      changes
+|*    special handling if the style of the grid alignment changes
 |*
 *************************************************************************/
 
diff --git a/sw/source/core/layout/wsfrm.cxx b/sw/source/core/layout/wsfrm.cxx
index e2600e3..323f857 100644
--- a/sw/source/core/layout/wsfrm.cxx
+++ b/sw/source/core/layout/wsfrm.cxx
@@ -581,7 +581,7 @@ void SwFrm::InsertBefore( SwLayoutFrm* pParent, SwFrm* pBehind )
     pUpper = pParent;
     pNext = pBehind;
     if( pBehind )
-    {   //Inert before pBehind.
+    {   //Insert before pBehind.
         if( 0 != (pPrev = pBehind->pPrev) )
             pPrev->pNext = this;
         else
@@ -643,18 +643,19 @@ void SwFrm::InsertBehind( SwLayoutFrm *pParent, SwFrm *pBefore )
 |*
 |*  Description         A chain of SwFrms gets inserted in an existing structure
 |*
-|*  Until now this is used to insert a SectionFrame which may has some siblings
-|*  into an existing structure.
+|*  Until now this is used to insert a SectionFrame (which may have some
+|*  siblings) into an existing structure.
 |*
 |*  If the third parameter is NULL, this method is (besides handling the
 |*  siblings) equal to SwFrm::InsertBefore(..)
 |*
 |*  If the third parameter is passed, the following happens:
 |*  - this becomes pNext of pParent
-|*  - pSct becomes pNext of the last on in the this-chains
+|*  - pSct becomes pNext of the last one in the this-chain
 |*  - pBehind is reconnected from pParent to pSct
-|*  This leads to: a SectionFrm (pParent) won't be connected, but pParent get
-|*  split up into two siblings (pParent+pSect) and inserted between.
+|*  The purpose is: a SectionFrm (this) won't become a child of another
+|*  SectionFrm (pParent), but pParent gets split into two siblings
+|*  (pParent+pSect) and this is inserted between.
 |*
 |*************************************************************************/
 void SwFrm::InsertGroupBefore( SwFrm* pParent, SwFrm* pBehind, SwFrm* pSct )
@@ -694,7 +695,7 @@ void SwFrm::InsertGroupBefore( SwFrm* pParent, SwFrm* pBehind, SwFrm* pSct )
             pLast->pUpper = GetUpper();
         }
         if( pBehind )
-        {   //Insert befor pBehind.
+        {   // Insert before pBehind.
             if( pBehind->GetPrev() )
                 pBehind->GetPrev()->pNext = NULL;
             else
@@ -733,7 +734,7 @@ void SwFrm::InsertGroupBefore( SwFrm* pParent, SwFrm* pBehind, SwFrm* pSct )
         }
         pLast->pNext = pBehind;
         if( pBehind )
-        {   //Insert befor pBehind.
+        {   // Insert before pBehind.
             if( 0 != (pPrev = pBehind->pPrev) )
                 pPrev->pNext = this;
             else
@@ -838,8 +839,10 @@ void SwCntntFrm::Paste( SwFrm* pParent, SwFrm* pSibling)
         {
             if ( GetPrev()->Frm().Height() !=
                  GetPrev()->Prt().Height() + GetPrev()->Prt().Top() )
-                //Take the frame into account?
+            {
+                // Take the border into account?
                 GetPrev()->_InvalidatePrt();
+            }
             // OD 18.02.2003 #104989# - force complete paint of previous frame,
             // if frame is inserted at the end of a section frame, in order to
             // get subsidiary lines repainted for the section.
@@ -933,9 +936,8 @@ void SwCntntFrm::Cut()
 
     if( 0 != (pFrm = GetIndNext()) )
     {
-        //The old follower may calculated a gap to the predecessor which now
-        //becomes obsolete or different respectively as it becomes the first
-        //one itself.
+        // The old follow may have calculated a gap to the predecessor which
+        // now becomes obsolete or different as it becomes the first one itself
         pFrm->_InvalidatePrt();
         pFrm->_InvalidatePos();
         pFrm->InvalidatePage( pPage );
@@ -971,8 +973,8 @@ void SwCntntFrm::Cut()
             pFrm->_InvalidatePos();
             pFrm->InvalidatePage( pPage );
         }
-        //If I'm (was) the only CntntFrm in my upper, he has to do the
-        //retouching.
+        // If I'm (was) the only CntntFrm in my upper, it has to do the
+        // retouching. Also, perhaps a page became empty.
         else
         {   SwRootFrm *pRoot = getRootFrm();
             if ( pRoot )
@@ -1045,7 +1047,7 @@ void SwCntntFrm::Cut()
                          ( pUp->IsFtnFrm() && pUp->IsColLocked() ) )
                     {
                         pSct->DelEmpty( sal_False );
-                        // If a loosened area may not be deleted then at least
+                        // If a locked section may not be deleted then at least
                         // its size became invalid after removing its last
                         // content.
                         pSct->_InvalidateSize();
@@ -1153,7 +1155,7 @@ void SwLayoutFrm::Paste( SwFrm* pParent, SwFrm* pSibling)
     if( (Frm().*fnRect->fnGetHeight)() )
     {
         // AdjustNeighbourhood is now also called in columns which are not
-        // placed inside the frame
+        // placed inside a frame
         sal_uInt8 nAdjust = GetUpper()->IsFtnBossFrm() ?
                 ((SwFtnBossFrm*)GetUpper())->NeighbourhoodAdjustment( this )
                 : NA_GROW_SHRINK;
@@ -1190,7 +1192,7 @@ void SwLayoutFrm::Cut()
     SwLayoutFrm *pUp = GetUpper();
 
     // AdjustNeighbourhood is now also called in columns which are not
-    // placed inside the frame
+    // placed inside a frame
 
     // Remove must not be called before a AdjustNeighbourhood, but it has to
     // be called before the upper-shrink-call, if the upper-shrink takes care
@@ -1338,9 +1340,9 @@ SwTwips SwFrm::Shrink( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
 |*       below a footnote boss (page/column) and its size changed.
 |*       There's always a frame which takes the maximum possible space (the
 |*       frame which contains the Body.Text) and zero or more frames which
-|*       only take the space needed (header/footer area, footnote).
-|*       If one of frames changed, the body-text-frame has to grow or shrink
-|*       accordingly; even tough it's fixed.
+|*       only take the space needed (header/footer area, footnote container).
+|*       If one of these frames changes, the body-text-frame has to grow or
+|*       shrink accordingly, even tough it's fixed.
 |*       !! Is it possible to do this in a generic way and not restrict it to
 |*       the page and a distinct frame which takes the maximum space (controlled
 |*       using the FrmSize attribute)? Problems: What if multiple frames taking
@@ -1364,7 +1366,7 @@ SwTwips SwFrm::AdjustNeighbourhood( SwTwips nDiff, sal_Bool bTst )
     const ViewShell *pSh = getRootFrm()->GetCurrShell();
     const sal_Bool bBrowse = pSh && pSh->GetViewOptions()->getBrowseMode();
 
-    //The (Page-)Body only changes in BrwoseMode, but only if it does not
+    //The (Page-)Body only changes in BrowseMode, but only if it does not
     //contain columns.
     if ( IsPageBodyFrm() && (!bBrowse ||
           (((SwLayoutFrm*)this)->Lower() &&
@@ -1426,7 +1428,7 @@ SwTwips SwFrm::AdjustNeighbourhood( SwTwips nDiff, sal_Bool bTst )
             if ( pViewShell && !pUp->GetPrev() &&
                  pUp->Frm().Height() + nDiff < pViewShell->VisArea().Height() )
             {
-                //This means, that we have to invalidate adequate.
+                // This means that we have to invalidate adequately.
                 nChg = pViewShell->VisArea().Height() - pUp->Frm().Height();
                 nInvaAdd = -(nDiff - nChg);
             }
@@ -2649,7 +2651,7 @@ SwTwips SwLayoutFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
             {
                 if( IsTabFrm() )
                     ((SwTabFrm*)this)->SetComplete();
-                if ( Lower() )  //Can also be in the Join an be empty!
+                if ( Lower() )  // Can also be in the Join and be empty!
                     InvalidateNextPos();
             }
         }
@@ -2695,8 +2697,8 @@ SwTwips SwLayoutFrm::ShrinkFrm( SwTwips nDist, sal_Bool bTst, sal_Bool bInfo )
 |*  Description          Changes the size of the directly subsidiary Frm's
 |*      which have a fixed size, proportionally to the size change of the
 |*      PrtArea of the Frm's.
-|*      The variable Frm's are also proportionally adapted; they will grow/shrink
-|*      again oneself.
+|*      The variable Frms are also proportionally adapted; they will
+|*      grow/shrink again by themselves.
 |*
 |*************************************************************************/
 void SwLayoutFrm::ChgLowersProp( const Size& rOldSize )
@@ -3056,7 +3058,7 @@ void SwLayoutFrm::ChgLowersProp( const Size& rOldSize )
         if ( !pLowerFrm->GetNext() && pLowerFrm->IsRetoucheFrm() )
         {
             //If a growth took place and the subordinate elements can retouch
-            //oneself (currently Tabs, Sections and Cntnt) we trigger it.
+            //itself (currently Tabs, Sections and Cntnt) we trigger it.
             if ( rOldSize.Height() < Prt().SSize().Height() ||
                  rOldSize.Width() < Prt().SSize().Width() )
                 pLowerFrm->SetRetouche();
@@ -3129,7 +3131,7 @@ void SwLayoutFrm::Format( const SwBorderAttrs *pAttrs )
             {   bValidSize = sal_True;
 
                 //The size in VarSize is calculated using the content plus the
-                //frames.
+                // borders.
                 SwTwips nRemaining = 0;
                 SwFrm *pFrm = Lower();
                 while ( pFrm )
@@ -3350,11 +3352,11 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
 {
     //If there are columns involved, the size is adjusted using the last column.
     //1. Format content.
-    //2. Calculate height of the last column if it's too big, the Fly has to
+    //2. Calculate height of the last column: if it's too big, the Fly has to
     //   grow. The amount by which the Fly grows is not the amount of the
-    //   overhang because we have to act on the assumption that some bulk floats
+    //   overhang because we have to act on the assumption that some text flows
     //   back which will generate some more space.
-    //   In the first paragraph the amount which we grow by equals the overhang
+    //   The amount which we grow by equals the overhang
     //   divided by the amount of columns or the overhang itself if it's smaller
     //   than the amount of columns.
     //3. Go back to 1. until everything is stable.
@@ -3377,10 +3379,10 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
         // In column based sections nMaximum starts at the maximum value which
         // the surrounding defines, this can certainly be a value on which
         // content still juts out.
-        // If content still juts out, the columns are formated and nMinimum is
-        // adjusted accordingly, then the growth is done, at least by uMinDiff
-        // but not over a certain nMaximum. If no content juts out but there is
-        // still some space left in the column, shrinking is done accordingly, at
+        // The columns are formatted. If content still juts out, nMinimum is
+        // adjusted accordingly, then we grow, at least by uMinDiff but not
+        // over a certain nMaximum. If no content juts out but there is still
+        // some space left in the column, shrinking is done accordingly, at
         // least by nMindIff but not below the nMinimum.
         // Cancel as soon as no content juts out and the difference from minimum
         // to maximum is less than MinDiff or the maximum which was defined by
@@ -3392,7 +3394,7 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
         // handles such situations the code contains a few checks concerning
         // minimum and maximum which probably are never triggered.
         // 2. We use the same nMinDiff for shrinking and growing, but nMinDiff
-        // is more or less the smallest first line height and doesn't fit ideal
+        // is more or less the smallest first line height and doesn't seem ideal
         // as minimum value.
 
         long nMinimum = nMinHeight;
@@ -3484,7 +3486,7 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
             for ( sal_uInt16 i = 0; i < nNumCols; ++i )
             {
                 pCol->Calc();
-                // ColumnFrms have a BodyFrm now, which need to be calculated too
+                // ColumnFrms have a BodyFrm now, which needs to be calculated
                 pCol->Lower()->Calc();
                 if( pCol->Lower()->GetNext() )
                     pCol->Lower()->GetNext()->Calc();  // SwFtnCont
@@ -3570,7 +3572,7 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
                         nMaximum = nPrtHeight;  // Robust, but will this ever happen?
                     if( !nDiff ) // If only Flys jut over, we grow by nMinDiff
                         nDiff = nMinDiff;
-                    // If we should grow more than by nMindDiff we split it over
+                    // If we should grow more than by nMinDiff we split it over
                     // the columns
                     if ( Abs(nDiff - nMinDiff) > nNumCols && nDiff > (long)nNumCols )
                         nDiff /= nNumCols;
@@ -3598,7 +3600,8 @@ void SwLayoutFrm::FormatWidthCols( const SwBorderAttrs &rAttrs,
                     long nPrtHeight = (Prt().*fnRect->fnGetHeight)();
                     if ( nMaximum < nPrtHeight )
                         nDiff = nMaximum - nPrtHeight; // We grew over a working
-                        // height and shrink back it, but will this ever happen?
+                        // height and shrink back to it, but will this ever
+                        // happen?
                     else
                     {   // We have a new maximum, a size which fits for the content.
                         nMaximum = nPrtHeight;
@@ -3773,11 +3776,10 @@ void lcl_InvalidateCntnt( SwCntntFrm *pCnt, sal_uInt8 nInv )
             {
                 // To not call FindTabFrm() for each CntntFrm of a table and
                 // then invalidate the table, we remember the last CntntFrm of
-                // the table and stop to react to IsInTab() until we passed it
-                // up.
-                // When entering the table, LastSctCnt is set to null, so areas
-                // inside the table are correctly invalidated.
-                // If the table itself is placed in such an area the
+                // the table and ignore IsInTab() until we are past it.
+                // When entering the table, LastSctCnt is set to null, so
+                // sections inside the table are correctly invalidated.
+                // If the table itself is in a section the
                 // invalidation is done three times, which is acceptable.
                 if( !pLastTabCnt )
                 {
@@ -3862,7 +3864,7 @@ void SwRootFrm::InvalidateAllCntnt( sal_uInt8 nInv )
         pPage = (SwPageFrm*)(pPage->GetNext());
     }
 
-    //Invalidate the whole document content and the drawn Flys here.
+    //Invalidate the whole document content and the character bound Flys here.
     ::lcl_InvalidateCntnt( ContainsCntnt(), nInv );
 
     if( nInv & INV_PRTAREA )


More information about the Libreoffice-commits mailing list
diff --git a/sw/source/core/layout/findfrm.cxx b/sw/source/core/layout/findfrm.cxx
index a2c7bf0..a02eaeb 100644
--- a/sw/source/core/layout/findfrm.cxx
+++ b/sw/source/core/layout/findfrm.cxx
@@ -87,11 +87,11 @@ SwCntntFrm *SwPageFrm::FindLastBodyCntnt()
 
 const SwCntntFrm *SwLayoutFrm::ContainsCntnt() const
 {
-    //Search downwards the layout sheet and if there is no content, jump to the
-    //next sheet until content is found or "this" is leaved.
+    //Search downwards the layout leaf and if there is no content, jump to the
+    //next leaf until content is found or we leave "this".
     //Sections: Cntnt next to sections would not be found this way (empty
-    //sections directely next to CntntFrm) therefore we need to recursively
-    //search form them even if it's more complex.
+    //sections directly next to CntntFrm) therefore we need to recursively
+    //search for them even if it's more complex.
 
     const SwLayoutFrm *pLayLeaf = this;
     do
@@ -148,8 +148,8 @@ const SwCellFrm *SwLayoutFrm::FirstCell() const
 |*
 |*  SwLayoutFrm::ContainsAny
 |*
-|*  Description      like CotainsCntnt, but does not only return CntnFrms but
-|*  also ranges and tables.
+|*  like ComtainsCntnt, but does not only return CntntFrms but
+|*  also sections and tables.
 |*************************************************************************/
 
 // #130797#
@@ -157,8 +157,8 @@ const SwCellFrm *SwLayoutFrm::FirstCell() const
 // content of footnotes for sections.
 const SwFrm *SwLayoutFrm::ContainsAny( const bool _bInvestigateFtnForSections ) const
 {
-    //Search downwards the layout sheet and if there is no content, jump to the
-    //next sheet until content is found, "this" is leaved or until we found
+    //Search downwards the layout leaf and if there is no content, jump to the
+    //next leaf until content is found, we leave "this" or until we found
     //a SectionFrm or a TabFrm.
 
     const SwLayoutFrm *pLayLeaf = this;
@@ -380,7 +380,7 @@ const SwLayoutFrm *SwFrm::ImplGetNextLayoutLeaf( bool bFwd ) const
 |*
 |*      Walk back inside the tree: grab the subordinate Frm if one exists and
 |*      the last step was not moving up a level (this would lead to an infinite
-|*      up/down loop!). With this we get sure that during walking back we search
+|*      up/down loop!). With this we ensure that during walking back we search
 |*      through all sub trees. If we walked downwards we have to go to the end
 |*      of the chain first because we go backwards from the last Frm inside
 |*      another Frm. Walking forward works the same.
@@ -460,8 +460,8 @@ SwPageFrm* SwFrm::FindPageFrm()
 SwFtnBossFrm* SwFrm::FindFtnBossFrm( sal_Bool bFootnotes )
 {
     SwFrm *pRet = this;
     // Footnoteboses can't exists inside a table; also column based sections
     // don't contain footnote textes there
     if( pRet->IsInTab() )
         pRet = pRet->FindTabFrm();
     while ( pRet && !pRet->IsFtnBossFrm() )
@@ -642,11 +642,11 @@ const SwAttrSet* SwFrm::GetAttrSet() const
 |*         _FindNextCnt() visits tables and sections and only returns SwCntntFrms.
 |*
 |*  Description         Invalidates the position of the next frame.
-|*      This is the direct succesor or when talking about CntntFrms the next
+|*      This is the direct successor or in case of CntntFrms the next
 |*      CntntFrm which sits in the same flow as I do:
 |*      - body,
 |*      - footnote,
-|*      - in head-/footnote sections the notification only needs to be forwarded
+|*      - in headers/footers the notification only needs to be forwarded
 |*        inside the section
 |*      - same for Flys
 |*      - Cntnts in tabs remain only inside their cell
@@ -806,10 +806,7 @@ SwFrm *SwFrm::_FindNext()
     if( pRet && pRet->IsInSct() )
     {
         SwSectionFrm* pSct = pRet->FindSctFrm();
-        //Fussnoten in spaltigen Rahmen duerfen nicht den Bereich
-        //liefern, der die Fussnoten umfasst
-
-        //Footnotes in column frames must not return the section which
+        //Footnotes in frames with columns must not return the section which
         //contains the footnote
         if( !pSct->IsAnLower( this ) &&
             (!bFtn || pSct->IsInFtn() ) )
@@ -1128,7 +1125,7 @@ SwFrm *SwFrm::_FindPrev()
                                             : (SwFrm*)pPrvCnt;
                 return pRet;
             }
-            else    //foot-/or head section or Fly
+            else // footer or header or Fly
             {
                 const SwFrm *pUp = pThis->GetUpper();
                 const SwFrm *pCntUp = pPrvCnt->GetUpper();
@@ -1174,11 +1171,9 @@ void SwFrm::ImplInvalidateNextPos( sal_Bool bNoFtn )
             if( pFrm )
             {
                 if ( pFrm->IsSctFrm())
-                { // Damit der Inhalt eines Bereichs die Chance erhaelt,
-                  // die Seite zu wechseln, muss er ebenfalls invalidiert werden.
-
-                  // We need to invalidate a sections content so it gets the
-                  // chance to change the page.
+                {
+                    // We need to invalidate the section's content so it gets
+                    // the chance to flow to a different page.
                     SwFrm* pTmp = ((SwSectionFrm*)pFrm)->ContainsAny();
                     if( pTmp )
                         pTmp->InvalidatePos();
@@ -1251,8 +1246,8 @@ void SwFrm::InvalidateNextPrtArea()
 |*
 |*    lcl_IsInColSect()
 |*
-|*      returns sal_True, if the frame _directly_ sits in a column section but
-|*      not if it sits in a table which itself sits in a column section.
+|* returns true if the frame _directly_ sits in a section with columns
+|* but not if it sits in a table which itself sits in a section with columns.
 |*************************************************************************/
 
 sal_Bool lcl_IsInColSct( const SwFrm *pUp )
@@ -460,8 +460,8 @@ SwPageFrm* SwFrm::FindPageFrm()
 {
     SwFrm *pRet = this;
-    // Footnoteboses can't exists inside a table; also column based sections
-    // don't contain footnote textes there
+    // Footnote bosses can't exist inside a table; also sections with columns
+    // don't contain footnote texts there
     if( pRet->IsInTab() )
         pRet = pRet->FindTabFrm();
diff --git a/sw/source/core/layout/paintfrm.cxx b/sw/source/core/layout/paintfrm.cxx
index 271ee0b..dac3e27 100644
--- a/sw/source/core/layout/paintfrm.cxx
+++ b/sw/source/core/layout/paintfrm.cxx
@@ -198,7 +198,7 @@ SV_DECL_VARARR( SwLRects, SwLineRect, 100 )
 
 class SwLineRects : public SwLRects
 {
-    sal_uInt16 nLastCount;  //avoid unnecessary cycles in PainLines
+    sal_uInt16 nLastCount;  //avoid unnecessary cycles in PaintLines
 public:
     SwLineRects() : nLastCount( 0 ) {}
     void AddLineRect( const SwRect& rRect,  const Color *pColor, const SvxBorderStyle nStyle,
@@ -224,7 +224,7 @@ public:
 static ViewShell *pGlobalShell = 0;
 
 //Only repaint the Fly content as well as the background of the Fly content if
-//a metafile is subtracted from the Fly.
+//a metafile is taken of the Fly.
 static sal_Bool bFlyMetafile = sal_False;
 static OutputDevice *pFlyMetafileOut = 0;
 
@@ -1374,7 +1374,7 @@ void MA_FASTCALL lcl_SubtractFlys( const SwFrm *pFrm, const SwPageFrm *pPage,
         //For character bound Flys only examine those Flys in which it is not
         //anchored itself.
         //Why only for character bound ones you may ask? It never makes sense to
-        //subtract borders in which it is anchored itself right?
+        //subtract frames in which it is anchored itself right?
         if ( pSelfFly && pSelfFly->IsLowerOf( pFly ) )
             continue;
 
@@ -1400,14 +1400,14 @@ void MA_FASTCALL lcl_SubtractFlys( const SwFrm *pFrm, const SwPageFrm *pPage,
             if ( pSdrObj->GetLayer() == pTmp->GetLayer() )
             {
                 if ( pSdrObj->GetOrdNumDirect() < pTmp->GetOrdNumDirect() )
-                    //In the same layer we only observe those how are overhead.
+                    //In the same layer we only observe those that are above.
                     continue;
             }
             else
             {
                 if ( !bLowerOfSelf && !pFly->GetFmt()->GetOpaque().GetValue() )
                     //From other layers we are only interested in non
-                    //transparent ones or those how are internal
+                    //transparent ones or those that are internal
                     continue;
                 bStopOnHell = sal_False;
             }
@@ -1418,14 +1418,14 @@ void MA_FASTCALL lcl_SubtractFlys( const SwFrm *pFrm, const SwPageFrm *pPage,
             if ( pSdrObj->GetLayer() == pTmp->GetLayer() )
             {
                 if ( pSdrObj->GetOrdNumDirect() < pTmp->GetOrdNumDirect() )
-                    //In the same layer we only observe those how are overhead.
+                    //In the same layer we only observe those that are above.
                     continue;
             }
             else
             {
                 if ( !pFly->IsLowerOf( pRetoucheFly ) && !pFly->GetFmt()->GetOpaque().GetValue() )
                     //From other layers we are only interested in non
-                    //transparent ones or those how are internal
+                    //transparent ones or those that are internal
                     continue;
                 bStopOnHell = sal_False;
             }
@@ -2751,11 +2751,11 @@ namespace
 |*
 |*  Description
 |*      Paint once for every visible page which is touched by Rect.
-|*      1. Paint frames and backgrounds.
-|*      2. Paint the draw layer (frames and drawing objects) which are located
-|*         under the document (hell).
+|*      1. Paint borders and backgrounds.
+|*      2. Paint the draw layer (frames and drawing objects) that is
+|*         below the document (hell).
 |*      3. Paint the document content (text)
-|*      4. Paint the draw layer which are located above the document.
+|*      4. Paint the draw layer that is above the document.
 |*************************************************************************/
 
 void
@@ -3224,8 +3224,8 @@ void SwLayoutFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
                 //This could lead to the situation, that other parts of the
                 //paragraph won't be repainted at all. The only solution seems
                 //to be an invalidation of the window.
-                //To not make it to severe the rectangle is limited by
-                //repainting the desired part and only invalidating the
+                //To not make it too severe the rectangle is limited by
+                //painting the desired part and only invalidating the
                 //remaining paragraph parts.
                 if ( aPaintRect.Left()  == rRect.Left() &&
                      aPaintRect.Right() == rRect.Right() )
@@ -3631,7 +3631,7 @@ sal_Bool SwFlyFrm::IsPaint( SdrObject *pObj, const ViewShell *pSh )
 
             //Try to avoid displaying the intermediate stage, Flys which don't
             //overlap with the page on which they are anchored won't be
-            //repainted.
+            //painted.
             //HACK: exception: printing of frames in tables, those can overlap
             //a page once in a while when dealing with oversized tables (HTML).
             SwPageFrm *pPage = pFly->FindPageFrm();
@@ -3718,8 +3718,8 @@ void MA_FASTCALL lcl_PaintLowerBorders( const SwLayoutFrm *pLay,
 void SwFlyFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
 {
     //because of the overlapping of frames and drawing objects the flys have to
     //paint their frames (and those of the internal ones) directly.
     //i.e. #33066#
     pLines->LockLines(sal_True);
 
     SwRect aRect( rRect );
@@ -3831,7 +3831,7 @@ void SwFlyFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
                      ( pNoTxt && !bIsGraphicTransparent ) )
                 {
                     //What we actually want to paint is the small stripe between
-                    //PrtArea and outer frame.
+                    //PrtArea and outer border.
                     SwRect aTmp( Prt() ); aTmp += Frm().Pos();
                     aRegion -= aTmp;
                 }
@@ -6026,7 +6026,7 @@ void SwFrm::PaintBackground( const SwRect &rRect, const SwPageFrm *pPage,
     delete pTmpBackBrush;
 
     //Now process lower and his neighbour.
     //We end this as soon as a Frn leaves the chain and therefore is not a lower
     //of me anymore
     const SwFrm *pFrm = GetLower();
     if ( pFrm )
@@ -6194,7 +6194,7 @@ void MA_FASTCALL lcl_RefreshLine( const SwLayoutFrm *pLay,
         //fly.
         //The end point moves to the start if the end point lies in a fly or we
         //have a fly between starting point and end point.
-        //Using this, every position is outputted one by one.
+        // In this way, every position is output one by one.
 
         //If I'm a fly I'll only avoid those flys which are places 'above' me;
         //this means those who are behind me in the array.
@@ -6220,7 +6220,7 @@ void MA_FASTCALL lcl_RefreshLine( const SwLayoutFrm *pLay,
             const SwFlyFrm *pFly = pObj ? pObj->GetFlyFrm() : 0;
 
             //I certainly won't avoid myself, even if I'm placed _inside_ the
-            //fly I won't avoid.
+            //fly I won't avoid it.
             if ( !pFly || (pFly == pLay || pFly->IsAnLower( pLay )) )
             {
                 aIter.Next();
@@ -6597,8 +6597,8 @@ void SwLayoutFrm::PaintSubsidiaryLines( const SwPageFrm *pPage,
 |*  SwPageFrm::RefreshExtraData(), SwLayoutFrm::RefreshExtraData()
 |*
 |* Description          Refreshes all extra data (line breaks a.s.o) of the
-|*                      page. Basically only those objects are considered who
-|*                      edgewise loom inside the Rect.
+|*                      page. Basically only those objects are considered which
+|*                      horizontally overlap the Rect.
 |*
 |*************************************************************************/
 
@@ -6723,7 +6723,7 @@ const Font& SwPageFrm::GetEmptyPageFont()
 |*    Description       Retouch for a section.
 |*      Retouch will only be done, if the Frm is the last one in his chain.
 |*      The whole area of the upper which is located below the Frm will be
-|*      using PainBackground cleared.
+|*      cleared using PaintBackground.
 |*************************************************************************/
 
 void SwFrm::Retouche( const SwPageFrm * pPage, const SwRect &rRect ) const
@@ -6755,8 +6755,8 @@ void SwFrm::Retouche( const SwPageFrm * pPage, const SwRect &rRect ) const
 
             GetUpper()->PaintBaBo( rRetouche, pPage, sal_True );
 
-            //Hell and Heaven needs to be refreshed too.
-            //To avoid recursion my retouch flag needs to be reseted first!
+            //Hell and Heaven need to be refreshed too.
+            //To avoid recursion my retouch flag needs to be reset first!
             ResetRetouche();
             SwRect aRetouchePart( rRetouche );
             if ( aRetouchePart.HasArea() )
@@ -6803,7 +6803,7 @@ void SwFrm::Retouche( const SwPageFrm * pPage, const SwRect &rRect ) const
         of the frame transparency is considered and its color is not "no fill"/"auto fill"
     ---- old description in german:
     Description         Returns the Backgroundbrush for the area of the Frm.
-        The Brush is defined from it self or from an upper, the first Brush is
+        The Brush is defined by the Frm or by an upper, the first Brush is
         used. If no Brush is defined for a Frm, sal_False is returned.
 
     @param rpBrush
@@ -3718,8 +3718,8 @@ void MA_FASTCALL lcl_PaintLowerBorders( const SwLayoutFrm *pLay,
 {
     //because of the overlapping of frames and drawing objects the flys have to
-    //paint their frames (and those of the internal ones) directly.
-    //i.e. #33066#
+    //paint their borders (and those of the internal ones) directly.
+    //e.g. #33066#
     pLines->LockLines(sal_True);
 
@@ -6026,7 +6026,7 @@ void SwFrm::PaintBackground( const SwRect &rRect, const SwPageFrm *pPage,
 
     //Now process lower and his neighbour.
-    //We end this as soon as a Frn leaves the chain and therefore is not a lower
+    //We end this as soon as a Frm leaves the chain and therefore is not a lower
     //of me anymore
     const SwFrm *pFrm = GetLower();